@@ -118,7 +118,7 @@ def format_issue( issue , mode = 0 ):
     elif status_string in ["open","unassigned","reopened"]:
         status_color="red"
     if not sys.stdout.isatty():
-        colorfunc = lambda *a:str(a[0])
+        colorfunc = lambda *a,**k:str(a[0])
         color=False
     
     
@@ -134,15 +134,16 @@ def format_issue( issue , mode = 0 ):
             fields["summary"] = issue["summary"]
             fields["link"] = colorfunc( "%s/browse/%s" % ( jirabase, issue["key"]), "white",attrs=["underline"])
         if mode >= 1:
-            fields["description"] = issue["description"]
+            fields["description"] = issue.setdefault("description","")
         if mode < 0:
             url_str = colorfunc("%s/browse/%s" % (jirabase, issue["key"]), "white", attrs=["underline"])
             ret_str = colorfunc(issue["key"],status_color) +" "+ issue["summary"] + " " + url_str
             if not color:
-                ret_str += "[%s]" % get_issue_status(issue["status"]) + issue["status"]
+                ret_str += " [%s] " % get_issue_status(issue["status"])
             return ret_str
         return "\n".join( " : ".join((k.ljust(20),v)) for k,v in fields.items() ) + "\n"
     except Exception,e:
+            print e
             return "%s: Not found" % issue["key"]
 
 
@@ -177,7 +178,14 @@ def main():
     """
     """
     example_usage = """
-for documentation see: http://hg.indydevs.org/jira-cli
+------------------------------------------------------------------------------------------
+view jira: jira-cli BE-193
+view multiple jiras: jira-cli XYZ-123 ZZZ-123 ABC-123
+add a comment: jira-cli -j BE-193 -c "i am sam"
+create a new issue: jira-cli -n bug -p BE -t "i am sam" "and this is my long description
+ending
+here"
+------------------------------------------------------------------------------------------
 """
     parser = optparse.OptionParser()
     parser.usage = example_usage
